@@ -17,12 +17,12 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
  */
-#include <wibble/config.h>
 #include <wibble/exception.h>
 
 #include <string.h> // strerror_r
 #include <errno.h>
 
+#include <cstdlib>
 #include <typeinfo>
 #include <sstream>
 #include <iostream>
@@ -34,6 +34,8 @@ using namespace std;
 namespace wibble {
 namespace exception {
 
+std::vector< std::string > AddContext::s_context;
+
 void DefaultUnexpected()
 {
 	try {
